function [TUVMean,TUVCrossFlowStd,TUVAlongFlowStd]=GetHFRadarMeansSTD(TUVIn)
%
%  [TUVMean,TUVCrossFlowStd,TUVAlongFlowStd]=GetHFRadarMeansSTD(TUVIn);
%
%  This returns the mean flow vectors at each point, and the standard
%  deviations in the along-mean-flow and cross-mean-flow direction.  The
%  (x,y) components of the deviations are returned so that they can be
%  plotted with teh HF Radar Toolbox routines.
%
%  CMH, Jan 2008
%
%  The Timestamp in each output structure is set to 1 (so only 1 column in
%  the output structure)
%
TUVMean=TUVIn;
TUVCrossFlowStd=TUVIn;
TUVAlongFlowStd=TUVIn;
%
%  Obtain the mean speeds
%
UMeanVel=nanmean(TUVIn.U');
UMeanVel=UMeanVel';
VMeanVel=nanmean(TUVIn.V');
VMeanVel=VMeanVel';
%
TUVMean.TimeStamp=1;
TUVMean.U=UMeanVel;
TUVMean.V=VMeanVel;
%
%  obtain the mean flow directions
%
[MagMean,DirMean]=ConvertHFComponentsToSpeedDir(TUVMean.U,TUVMean.V);
%
%  Rotate the measurements to correspond to the mean flow directions
%  at each point
%
[SerERotated,SerNRotated]=RotateHFMeas(TUVIn.U,TUVIn.V,DirMean);
%
%  obtain the standard deviations
%
UStd=nanstd(SerERotated');
UStd=UStd';
%
VStd=nanstd(SerNRotated');
VStd=VStd';
%
[EastOut,NorthOut]=ConvertHFSpeedDirToComponents(UStd,DirMean+90,'TOWARD');
%
TUVCrossFlowStd.TimeStamp=1;
TUVCrossFlowStd.U=EastOut;
TUVCrossFlowStd.V=NorthOut;
%
[EastOut,NorthOut]=ConvertHFSpeedDirToComponents(VStd,DirMean,'TOWARD');
%
TUVAlongFlowStd.TimeStamp=1;
TUVAlongFlowStd.U=EastOut;
TUVAlongFlowStd.V=NorthOut;
%
%  the routine is done
%
return;
%
