function [PerCovStats]=GetPerHFCoverageTest(FieldIn,MeasDNumTimes,WindowLength)
%
%  GetPerHFCoverageTest(FieldIn,MeasDNumTimes,WindowLength);
%
%  FieldIn are teh measurements, rows are positions, columns are times
%  MeasDNumTimes is the associated time axis measured in days
%  WindowLength is the length of the sliding window to use in hours
%
%  PerCovStats.MinMeas - the mimum percent coverage found for the sliding
%  window at each point and time
%  PerCovStats.MaxMeas - the maximum percent coverage found for the sliding
%  window at each point and time
%  PerCovStats.TypMeas - the typical percent coverage found for the sliding
%  window at each point and time
%
%  Modified to assume hourly measurements!  Nov 2008
%
PerCovStats.MinMeas=NaN*ones(size(FieldIn));
PerCovStats.MaxMeas=NaN*ones(size(FieldIn));
PerCovStats.TypMeas=NaN*ones(size(FieldIn));
PerCovStats.MedianMeas=NaN*ones(size(FieldIn));
%
[TotPoints,TotTimes]=size(FieldIn);
%TemTimeDiff=MeasDNumTimes(2:TotTimes)-MeasDNumTimes(1:TotTimes-1);
%TemTimeDiff=24*TemTimeDiff;  % now in hours
%TypTimeDiff=mode(TemTimeDiff);  % typical spacing in hours
%
MaxMeasPerWindow=WindowLength+1;  % b/c of the way that the window length
%  is used later in the routine
MaxWindowsPerMeasurement=MaxMeasPerWindow;  %  the number of sliding windows
%
FieldTimeStart=nanmin(MeasDNumTimes);
FieldTimeEnd=nanmax(MeasDNumTimes);
%
for jtime=1:TotTimes,
    %
    if isequal(rem(jtime,50),0),
        TemStr=['Calculating percent cov windows, time ' num2str(jtime) ' of ' num2str(TotTimes)];
        disp(TemStr)
    end
    %
    TemCovMeas=NaN*ones(TotPoints,MaxWindowsPerMeasurement);
    %
    TimeToGet=MeasDNumTimes(jtime);
    %
    for jwind=1:MaxWindowsPerMeasurement,
        %
        TimeStart=TimeToGet-((MaxMeasPerWindow-1)/24)-0.001+((jwind-1)/24);
        TimeEnd=TimeStart+((MaxMeasPerWindow-1)/24)+0.002;
        %
        if (TimeStart>=FieldTimeStart)&&(TimeEnd<=FieldTimeEnd),
            %
            IndicesToObtain=find((MeasDNumTimes>=TimeStart)&(MeasDNumTimes<=TimeEnd));
            %
            if numel(IndicesToObtain>0),
                %
                FieldExtract=FieldIn(:,IndicesToObtain)';
                FieldExtract=sum(~isnan(FieldExtract));
                TemCovMeas(:,jwind)=FieldExtract;
                %
            end
        end
    end
    %
    temmark=find(~isnan(nansum(TemCovMeas)));
    if numel(temmark)>0,
        TemCovMeas=TemCovMeas(:,temmark);
        TemSer=nanmin(TemCovMeas');
        PerCovStats.MinMeas(:,jtime)=TemSer';
        TemSer=nanmax(TemCovMeas');
        PerCovStats.MaxMeas(:,jtime)=TemSer';
        TemSer=mode(TemCovMeas');
        PerCovStats.TypMeas(:,jtime)=TemSer';
        TemSer=nanmedian(TemCovMeas');
        PerCovStats.MedianMeas(:,jtime)=TemSer';
    end
    %
end
%
PerCovStats.MinMeas=(100/MaxMeasPerWindow)*PerCovStats.MinMeas;
PerCovStats.MaxMeas=(100/MaxMeasPerWindow)*PerCovStats.MaxMeas;
PerCovStats.TypMeas=(100/MaxMeasPerWindow)*PerCovStats.TypMeas;
PerCovStats.MedianMeas=(100/MaxMeasPerWindow)*PerCovStats.MedianMeas;
%
%  the routine is done
%
return;
%