function [ProjectedVectors]=GetProjectedRadialComponents(LonLatLocations,MeanUVels,MeanVVels,SiteOrigin)
%
%  [ProjectedVectors]=GetProjectedRadialComponents(LonLatLocations,MeanUVels,MeanVVe
%  ls,SiteOrigin);
%
%  Number of LonLat Locations and U Velocities and V Velocities need to be
%  the sams.  Only one Siteorigin allowed.  Column Matrices.
%
%  ProjectedVectors are the radial component of the input vectors.
%  Positive direction toward the site origin.
%
NumLonLat=numel(LonLatLocations(:,1));
NumUVel=numel(MeanUVels);
NumVVel=numel(MeanVVels);
%
if ~isequal(NumLonLat,NumUVel),
    ProjectedVectors=NaN;
    return;
end
%
if ~isequal(NumLonLat,NumVVel),
    ProjectedVectors=NaN;
    return;
end
%
[s,a12,a21]=m_idist(LonLatLocations(:,1),LonLatLocations(:,2),SiteOrigin(1),SiteOrigin(2),'wgs84');
%
%  NaNs indicate vectors that are too close to determine heading, etc.
%  Don;t worry about those here.
%
%  Get unit vectors
%
VectorsTowardOrigin.X=sind(a12);  % these have unit length, so do not need in denominator for the projection
VectorsTowardOrigin.Y=cosd(a12);
%
UnitVectors=[VectorsTowardOrigin.X VectorsTowardOrigin.Y];
%
VelVectors=[MeanUVels MeanVVels];
%
TemNumerator=dot(UnitVectors,VelVectors,2);  %  this is the magnitude!
%
ProjectedVectors=TemNumerator;
%
%  the routine is done
%
return;
%
