function [RadialStats,Rcat]=GetRadialStatistics(Rorig,filenamesout,RadialMaskFiles,TimeVect6Comp,TimeVect4Comp)
%
%  [RadialStats,Rcat]=GetRadialStatistics(Rorig,filenamesout,RadialMaskFiles,TimeVect6Comp,TimeVect4Comp);
%
%  Rorig is teh array of radials that has already been read in
%  RadialMaskFiles is the mak file set, in order that the sites are read in
%  filenamesout is the cell array of files
%  TimeVect6Comp is the YY MMM DD HH MM SS times that were searched for -
%     just a set of times going from least time to last
%  TimeVect4Comp is the 4 component set of times, but redefined so that
%      each file is associated with a set of times (i.e., the first time
%      repeats until all files from the sites are read in, then the second time
%      repeats, etc.)  This parameter is output by SetUpSFBayFileNames, for
%      example.
%  Rcat is the "liightly gridded:, temporally concatened set of radials
%
%  This is a bit redundant and repetitiouus the way that it is set up
%
RadialStats.filenames=filenamesout;
NumFiles=numel(filenamesout);
RadialStats.SiteNames=cell(NumFiles,1);  %redundant, given the file name, but will be useful later
RadialStats.FileTimes=NaN*zeros(NumFiles,4);  % also redundant, but will be useful later
RadialStats.FileTimeStamp=NaN*zeros(NumFiles,1);  % time stamp of the file
RadialStats.FileFound=NaN*zeros(NumFiles,1);  % 1 if found, zero if not  (1 is defined to be good in the stats)
RadialStats.DataFound=NaN*zeros(NumFiles,1); % 1 if valid, zero if not
RadialStats.NotWobblyFiles=NaN*zeros(NumFiles,1);  % 1 if not wobbly, zero if wobbly
RadialStats.MatchingTimeStamps=NaN*zeros(NumFiles,1); % 1 if matching, zero if not
RadialStats.GriddedCurrentsUnique=NaN*zeros(NumFiles,1);  % 1 if more than 70% of the gridded currents are different from preeding and following file
RadialStats.NonNanGriddedCurrentsUnique=NaN*zeros(NumFiles,1);  % the unique flag can be misleading if alot of NaNs
RadialStats.PerDiffFwd=NaN*zeros(NumFiles,1);  % the percentage of NonNan meas that are different from the next time
RadialStats.PerDiffBack=NaN*zeros(NumFiles,1);  % % the percentage of NonNan meas that are different from the previous time
RadialStats.NumRadsInMask=NaN*zeros(NumFiles,1);
RadialStats.NumRadsOutSideMask=NaN*zeros(NumFiles,1);
RadialStats.NumRadsTotal=NaN*zeros(NumFiles,1);
RadialStats.MaxRange=NaN*zeros(NumFiles,1);
RadialStats.MinRange=NaN*zeros(NumFiles,1);
RadialStats.MinBear=NaN*zeros(NumFiles,1);
RadialStats.MaxBear=NaN*zeros(NumFiles,1);
%
%  this loop is redundant, as filenames that do not exist return empty
%  radial structures.  Keep anyway, as it is possible for a filename to
%  exist and no data to be in the file.
%
%  do I need a loop?  - yes, for the check if the files exist
%
[NumTimes,NumCols]=size(TimeVect6Comp);
SitesOut=repmat(SiteCodes,NumTimes,1);
RadialStats.SiteNames=SitesOut;
RadialStats.FileTimes=TimeVect4Comp;
RadialStats.FileTimeStamp=datenum([TimeVect4Comp zeros(NumFiles,2)]);
clear TemTimes
%
disp('starting basic stat calculation')
%
for jfile=1:numel(filenamesout),
    %  check for file names
    if ~exist(filenamesout{jfile},'file'),
        RadialStats.FileFound(jfile)=0;
    else
        RadialStats.FileFound(jfile)=1;
    end
    % check for data
    if sum(isfinite(Rorig(jfile).RadComp))>0,  % change to reflect teh fact that some files can appear to have data
        RadialStats.DataFound(jfile)=1; % so check on issum(finite) instead of isempty  *****  added 27 aug 2007
    else
        RadialStats.DataFound(jfile)=0;
    end
    %  check additional parameters
    if ((RadialStats.FileFound(jfile)>0)&(RadialStats.DataFound(jfile)>0)),
        %  
        %  wobbly radial check  - next routine has errors for unknown
        %  reason
        %
        try
            [rs,bs] = getRangeBearSpacing(Rorig(jfile));
            dd = min( diff( unique( Rorig(jfile).RangeBearHead(:,2) ) ) );
            if isfinite(bs(1)) && isfinite(dd) && bs(1) > dd,
                RadialStats.NotWobblyFiles(jfile) = 0;
            else
                RadialStats.NotWobblyFiles(jfile) = 1;
            end
        catch
            RadialStats.NotWobblyFiles(jfile) = 2;  %%%% means something funny in file
        end
        %
        %  check for time stamp matching
        if abs(RadialStats.FileTimeStamp(jfile)-Rorig(jfile).TimeStamp) > 1/24/10,
            RadialStats.MatchingTimeStamps(jfile)=0;
        else
            RadialStats.MatchingTimeStamps(jfile)=1;
        end
        %  total number of radials
        RadialStats.NumRadsTotal(jfile)=sum(isfinite(Rorig(jfile).RadComp));
        %
    end
end
%
%  Get range bearing spacing and estimation of limits for the masked
%  radials
%
%  !!!  I can pass maskRdials empty structures, and only get warnings back.
%  Makes this part easy to program.
%
TotMaskFiles=repmat(RadialMaskFiles,NumTimes,1);
[Rmask,II]=maskRadials(Rorig,TotMaskFiles,true);
%
%  Process numrads for masked radials and range/bearing limits
%  parameters
%
disp('starting stat calculation of masked radials')
%
for jfile=1:numel(TotMaskFiles),
    %    numrads
    if ((RadialStats.FileFound(jfile)>0)&(RadialStats.DataFound(jfile)>0)),
        RadialStats.NumRadsInMask(jfile)=sum(isfinite(Rmask(jfile).RadComp));
        RadialStats.NumRadsOutSideMask(jfile)=RadialStats.NumRadsTotal(jfile)-RadialStats.NumRadsInMask(jfile);
    end
    % range bearing limits
    if sum(isfinite(Rmask(jfile).RadComp))>0,
        %
        IndexRadComp=find(isfinite(Rmask(jfile).RadComp));
        %
        RadialStats.MaxRange(jfile)=max(Rmask(jfile).RangeBearHead(IndexRadComp,1));
        RadialStats.MinRange(jfile)=min(Rmask(jfile).RangeBearHead(IndexRadComp,1));
        %
        RadialStats.MaxBear(jfile)=max(Rmask(jfile).RangeBearHead(IndexRadComp,2));
        RadialStats.MinBear(jfile)=min(Rmask(jfile).RangeBearHead(IndexRadComp,2));
        %
    end
    %
end
%
%  temporal concatenation
%
disp('temporal calculation of unmasked files')
%
Rcat = temporalConcatRadials( Rorig, 0.001, 0.49, 0.49, 0.5 );
%
%  empty structures typically end up first in the output.
%  But just in case they don't one time!!!  do as follows
%
FullStruct=NaN*ones(numel(Rcat),1);
%
for jsite=1:numel(Rcat),
    FullStruct(jsite)=double(~isempty(Rcat(jsite).SiteName));
end
%
TemFull=find(FullStruct);
%
Rcat=Rcat(TemFull);
%
%  the radials have been only slightly gridded by the above concatenation procedure
%
%  Step through site by site and check to see that the files at each sucessive time are unique
%  Only compares successive times when we have files...  if time skips,
%  that is not taken into account
%
PerDiffCut=70;  % 70% of the current data have to be different from one another as we step through time.... check RadComp
%
%  use 0.1 cm/s as a limit for sameness - why?  don;t really know, but
%  easy, will prevent roundoff, etc.
%
CutOffCheck=0.1;
%
disp('starting unique calculation of concatenated files')
%
for jsite=1:numel(Rcat),
    %
    TemRad=Rcat(jsite).RadComp;
    [NumPts,NumTimes]=size(TemRad);
    %
    TemRad2=TemRad;
    for jcol=1:NumTimes,
        TemRow=find(isfinite(TemRad2(:,jcol)));
        if numel(TemRow)>0,
            TemRad2=TemRad2(TemRow,:);
        end
    end
    %
    if numel(TemRad2)>0,
        [NumPts2,NumTimes2]=size(TemRad2);
    else
        NumPts2=1;  % just for ease of calculation in ppercentages pater
    end
    %
    %  at this point, we should have removed all NaNs from TemRad2
    %
    BackDiff=[zeros(NumPts,1) TemRad(:,2:NumTimes)-TemRad(:,1:NumTimes-1)];
    FwdDiff=[TemRad(:,2:NumTimes)-TemRad(:,1:NumTimes-1) zeros(NumPts,1)];
    %
    %  following is for TemRad2
    %
    if numel(TemRad2)>0,
            BackDiff2=[zeros(NumPts2,1) TemRad2(:,2:NumTimes)-TemRad2(:,1:NumTimes-1)];
            FwdDiff2=[TemRad2(:,2:NumTimes)-TemRad2(:,1:NumTimes-1) zeros(NumPts2,1)];
            if NumPts2==1,
                BackDiff2=[BackDiff2;BackDiff2];  %  we take a sum later
                FwdDiff2=[FwdDiff2;FwdDiff2];
            end
    end
    %
    %
    %  above will not work for NaN's......
    %
    %  So, if the measurement at the time before is a NaN, and the
    %  measurement at the current time is a NaN, then they are the same.
    %  Otherwise, they are different.  The same holds true for comparing to
    %  future times.
    %
    BackNanMatrix=double(isnan([TemRad(:,1) TemRad(:,1:NumTimes-1)]));
    FwdNanMatrix=double(isnan([TemRad(:,2:NumTimes) TemRad(:,NumTimes)]));
    %
    RadNanMatrix=double(isnan(TemRad));
    %
    temmark=find((BackNanMatrix>0.5)&(RadNanMatrix>0.5));  %  means that they are both NaNs, so not different
    %
    if numel(temmark)>0,
        BackDiff(temmark)=0;  % same value
    end
    %
    temmark=find((BackNanMatrix>0.5)&(RadNanMatrix<0.5));  %  means that they are different
    %
    if numel(temmark)>0,
        BackDiff(temmark)=10;  % any value will do
    end
    %
    temmark=find((BackNanMatrix<0.5)&(RadNanMatrix>0.5));  %  also means that they are different
    %
    if numel(temmark)>0,
        BackDiff(temmark)=10;  % any value will do
    end
    %
    %  last condition (both less than 0.5, or finite) is not necessary to
    %  check
    %
    temmark=find((FwdNanMatrix>0.5)&(RadNanMatrix>0.5));  %  means that they are both NaNs, so not different
    %
    if numel(temmark)>0,
        FwdDiff(temmark)=0;  % same value
    end
    %
    temmark=find((FwdNanMatrix>0.5)&(RadNanMatrix<0.5));  %  means that they are different
    %
    if numel(temmark)>0,
        FwdDiff(temmark)=10;  % any value will do
    end
    %
    temmark=find((FwdNanMatrix<0.5)&(RadNanMatrix>0.5));  %  also means that they are different
    %
    if numel(temmark)>0,
        FwdDiff(temmark)=10;  % any value will do
    end
    %
    TemmarkSame=find(abs(FwdDiff)<CutOffCheck);
    TemmarkDiff=find(abs(FwdDiff)>=CutOffCheck);
    if numel(TemmarkSame)>0,
        FwdDiff(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        FwdDiff(TemmarkDiff)=1;
    end
    %
    TemmarkSame=find(abs(BackDiff)<CutOffCheck);
    TemmarkDiff=find(abs(BackDiff)>=CutOffCheck);
    if numel(TemmarkSame)>0,
        BackDiff(TemmarkSame)=0;
    end
    if numel(TemmarkDiff)>0,
        BackDiff(TemmarkDiff)=1;
    end
    %  following for FwdDiff2 for TemRad2 - measurements wo/ NaNs
    if numel(TemRad2)>0,
        TemmarkSame=find(abs(FwdDiff2)<CutOffCheck);
        TemmarkDiff=find(abs(FwdDiff2)>=CutOffCheck);
        if numel(TemmarkSame)>0,
            FwdDiff2(TemmarkSame)=0;
        end
        if numel(TemmarkDiff)>0,
            FwdDiff2(TemmarkDiff)=1;
        end
    else
        FwdDiff2=zeros(numel(FwdDiff));  % will be flagged if no measurements
    end
    %  following for BackDiff2 for TemRad2 - measurements wo/ NaNs
    if numel(TemRad2)>0,
        TemmarkSame=find(abs(BackDiff2)<CutOffCheck);
        TemmarkDiff=find(abs(BackDiff2)>=CutOffCheck);
        if numel(TemmarkSame)>0,
            BackDiff2(TemmarkSame)=0;
        end
        if numel(TemmarkDiff)>0,
            BackDiff2(TemmarkDiff)=1;
        end
    else
        BackDiff2=zeros(numel(BackDiff));  % will be flagged if no measurements
    end
    %
    TotBackDiff=sum(BackDiff);
    TotFwdDiff=sum(FwdDiff);
    %
    TotBackDiff2=sum(BackDiff2);
    TotFwdDiff2=sum(FwdDiff2);
    %
    PerBackDiff=(100/NumPts)*TotBackDiff;
    PerFwdDiff=(100/NumPts)*TotFwdDiff;
    %
    if NumPts2==1,
         PerBackDiff2=(100/NumPts2)*(0.5*TotBackDiff2);  % to make up for doubling the rows.  Will also
         PerFwdDiff2=(100/NumPts2)*(0.5*TotFwdDiff2);   % enter this loop is numel(TemRad2)=0, but o.k. since all zeros anyway
    else
        PerBackDiff2=(100/NumPts2)*TotBackDiff2;
        PerFwdDiff2=(100/NumPts2)*TotFwdDiff2;
    end
    %
    %  !!!!!  now, the first column of PerBackDiff should be 100, since
    %  there is nothing before the first column to compare to (and given
    %  the logic that follows)
    %
    PerBackDiff(1)=100;
    PerFwdDiff(numel(PerFwdDiff))=100;  % same logic for the end of PerFwdDiff
    %
    PerBackDiff2(1)=100;
    PerFwdDiff2(numel(PerFwdDiff2))=100;  % same logic for the end of PerFwdDiff
    %
    BackFlag=zeros(1,NumTimes);
    FwdFlag=zeros(1,NumTimes);
    %
    BackFlag2=zeros(1,NumTimes);
    FwdFlag2=zeros(1,NumTimes);  
    %
    temmark=find(PerBackDiff<PerDiffCut);
    if numel(temmark)>0,
        BackFlag(temmark)=1;
    end
    %
    temmark=find(PerFwdDiff<PerDiffCut);
    if numel(temmark)>0,
        FwdFlag(temmark)=1;
    end
    %
    temmark=find(PerBackDiff2<PerDiffCut);
    if numel(temmark)>0,
        BackFlag2(temmark)=1;
    end
    %
    temmark=find(PerFwdDiff2<PerDiffCut);
    if numel(temmark)>0,
        FwdFlag2(temmark)=1;
    end
    %
    TotFlag2=sign(BackFlag2+FwdFlag2);  % now is flagged where bad
    TotFlag2=double(~TotFlag2);  % now flagged where good
    %
    TotFlag=sign(BackFlag+FwdFlag);  % now is flagged where bad
    TotFlag=double(~TotFlag);  % now flagged where good
    %
    %
    %  now this is a pain, but probably easier in the long run.
    %  go back, loop through, and set the flag to match the original series
    %  that we set
    %
    %  find the file numbers in the original list that
    %  correspond to the SiteCode that we have
    %
    OriginalFileNumbers=find(ismember(RadialStats.SiteNames,Rcat(jsite).SiteName));
    %
    if numel(OriginalFileNumbers)>0,
        %
        OriginalFileTimes=RadialStats.FileTimeStamp(OriginalFileNumbers);
        %
        %
        %  we could check to make sure that all of the above times have data,
        %  but we will only have measurements here for where we did have data,
        %  so no need
        %
        %  times in both cases should be sorted, but sort just to make sure
        %
        CurrSiteTimes=Rcat(jsite).TimeStamp;
        %
        %  turn into a column array (to match the saved statistics)
        %
        CurrSiteTimes=CurrSiteTimes';
        %
        [CurrSiteTimes,IndSort]=sort(CurrSiteTimes);
        %
        TotFlag=TotFlag';
        TotFlag=TotFlag(IndSort);
        %
        [OriginalFileTimes,IndSort]=sort(OriginalFileTimes);
        OriginalFileNumbers=OriginalFileNumbers(IndSort);
        %
        %  times, and variables, are now sorted according to time
        %
        [C,IA,IB]=intersect(CurrSiteTimes,OriginalFileTimes);
        %
        CurrSiteTimes=CurrSiteTimes(IA);  % these should all be o.k., equal to numel Rcat(jsite).TimeStamp
        TotFlag=TotFlag(IA);
        TotFlag2=TotFlag2(IA);
        PerFwdDiff2=PerFwdDiff2(IA);
        PerBackDiff2=PerBackDiff2(IA);
        %
        OriginalFileTimes=OriginalFileTimes(IB);
        OriginalFileNumbers=OriginalFileNumbers(IB);
        %
        %  now, they have been sorted, they should match, so....
        %
        try
            RadialStats.GriddedCurrentsUnique(OriginalFileNumbers)=TotFlag;  % sloppy programming, but leave for now
            RadialStats.NonNanGriddedCurrentsUnique(OriginalFileNumbers)=TotFlag2;
            RadialStats.PerDiffFwd(OriginalFileNumbers)=PerFwdDiff2;
            RadialStats.PerDiffBack(OriginalFileNumbers)=PerBackDiff2;
        catch
            disp('some mismatch occured')
            disp('parameters are:')
            jsite
            TotFlag
            OriginalFileNumbers
        end
        %
    end
end
%
return;
%
