function [NewTUV]=InterpTUVToNewGrid(OldTUV,NewGrid,GridSlop)
%
%  [NewTUV]=InterpTUVToNewGrid(OldTUV,NewGrid,GridSlop);
%
%  Spatial interpolation. Uses the routine extractVelocities to do this, so
%  see help comments of that routine.
%
%  TempStats and SpatialStats field stripped from the TUV structure if they
%  exist (actually, just not created).
%
%  ErrorEstimates, OtherSpatialVars, and OtherTemporalVars set to [].
%
%  Routine used to either resample one grid onto another, or to interpolate
%  a lower resolution set of vectors onto a higer resolution grid.
%
%  NewGrid is a lon/lat matrix - first column lon, second column lat
%
%  GridSlop is typicaally equal to the resolution of the old measurements
%  (2 km, etc)
%
NumTimes=numel(OldTUV.TimeStamp);
%
[NumPoints]=numel(NewGrid(:,1));
%
NewTUV=TUVstruct([NumPoints NumTimes]);
%
NewTUV.DomainName=OldTUV.DomainName;
NewTUV.CreationInfo=OldTUV.CreationInfo;
NewTUV.TimeStamp=OldTUV.TimeStamp;
NewTUV.TimeZone=OldTUV.TimeZone;
NewTUV.CreateTimeZone=OldTUV.CreateTimeZone;
%
%  Check for grid points that are the same and points that are different
%
[C,IA,IB]=intersect(OldTUV.LonLat,NewGrid,'rows');
%
[VelStructOut]=extractVelocities(OldTUV,NewGrid,GridSlop,'interp');  % calcuating and then replacing later is very slow
%
%  can change later if need be to increase speed
%
%  relpace interpolated values if some locations in common
%
if numel(IB)>0,
    VelStructOut.U(IB,:)=OldTUV.U(IA,:);
    VelStructOut.V(IB,:)=OldTUV.V(IA,:);
end
%
NewTUV.LonLat=NewGrid;
NewTUV.U=VelStructOut.U;
NewTUV.V=VelStructOut.V;
%
%  the routine is done
%
return;
%

