function [NewTUV]=InterpTUVToNewGrid2(OldTUV,NewGrid)
%
%  [NewTUV]=InterpTUVToNewGrid2(OldTUV,NewGrid);
%
%  uses griddata b/c of increase in speed.  GridSlop no longer used.
%
%  Spatial interpolation. Uses the routine extractVelocities to do this, so
%  see help comments of that routine.
%
%  TempStats and SpatialStats field stripped from the TUV structure if they
%  exist (actually, just not created).
%
%  ErrorEstimates, OtherSpatialVars, and OtherTemporalVars set to [].
%
%  Routine used to either resample one grid onto another, or to interpolate
%  a lower resolution set of vectors onto a higer resolution grid.
%
%  NewGrid is a lon/lat matrix - first column lon, second column lat
%
%  GridSlop is typicaally equal to the resolution of the old measurements
%  (2 km, etc)
%
NumTimes=numel(OldTUV.TimeStamp);
%
[NumPoints]=numel(NewGrid(:,1));
%
NewTUV=TUVstruct([NumPoints NumTimes]);
%
NewTUV.DomainName=OldTUV.DomainName;
NewTUV.CreationInfo=OldTUV.CreationInfo;
NewTUV.TimeStamp=OldTUV.TimeStamp;
NewTUV.TimeZone=OldTUV.TimeZone;
NewTUV.CreateTimeZone=OldTUV.CreateTimeZone;
%
%  Check for grid points that are the same and points that are different
%
[C,IA,IB]=intersect(OldTUV.LonLat,NewGrid,'rows');
%
for jtime=1:NumTimes,
   if sum(~isnan(OldTUV.U(:,jtime)))>0,
       [XNew,YNew,NewTUV.U(:,jtime)]=griddata(OldTUV.LonLat(:,1),OldTUV.LonLat(:,2),OldTUV.U(:,jtime),NewGrid(:,1),NewGrid(:,2),'linear');
       [XNew,YNew,NewTUV.V(:,jtime)]=griddata(OldTUV.LonLat(:,1),OldTUV.LonLat(:,2),OldTUV.V(:,jtime),NewGrid(:,1),NewGrid(:,2),'linear');
   else
       NewTUV.U(:,jtime)=NaN;
       NewTUV.V(:,jtime)=NaN;
   end
end
%
%  relpace interpolated values if some locations in common
%
if numel(IB)>0,
    NewTUV.U(IB,:)=OldTUV.U(IA,:);
    NewTUV.V(IB,:)=OldTUV.V(IA,:);
end
%
NewTUV.LonLat=NewGrid;
%
%  the routine is done
%
return;
%

