function PlotNonHFRadarData2(TemFigHandle,SymbType,SymbSize,ColorMatrices,MapPos)
%
%  PlotNonHFRadarData2(TemFigHandle,SymbType,SymbSize,ColorMatrices,MapPos);
%
%  Based on PlotNonHFRadarData, just plots sybols at the lat/lon positions
%  using the ColorMatrices vector (size of ColorMatrices is [NumPositions
%  3]).  NumPositions is the number of lon/lat points specified in MapPos.
%
%  PlotNonHFRadarData(TemFigHandle,TimeStep,DateNumSelect,TimeAxisIn,DataIn
%  ,SymbType,SymbRange,DataRange,ColorMapType,MapPos);
%
%  to place a symbol on a field of HF Radar velocity vectors
%
%  The value of TimeStep is used to plot the data, unless it is equal to
%  NaN.  If so, the value of DateNumSelect is used to find which value to
%  plot.  TimeAxisIn can be NaN if the TimeStep value is set.
%
%  Example useage, to plot TimeStep 1 with square symbols:
%
% PlotNonHFRadarData(TemFigHandle,1,NaN,NaN,'s',[10 20],[-15 15],'jet',[longitude latitude]);
%
%  modified 21 April 2009 ---  can also plot a full suite of data if
%  TimeStep in is a vector.  In that case, numel(DataIn) should equal
%  numel(longitude).  Only those points indexed by TimeStep will be
%  plotted.
%
%  Inputs:
%
%  TemFigHandle:  the handle of the prviously held figure of CODAR vectors
%  TimeStep:      the number of the data point to plot
%  DataIn:        the scalar Data - can be a row or column vector
%  SymbType:      the symbol to use for plotting - can be 's', or 'o', for
%                 example.  See plot for more details.
%  SymbRange:     The range in size of the symbols (MarkerSize).  Good ranges to use are
%                 [11 20].  Format is [minrange maxrange]
%  DataRange:     The range of the data to use for deciding what color to
%                 make the symbols and to scale the marker sizes
%  ColorMapType:  The colormap to use, see colormap.  'jet' is a good one
%                 if you want to vary from blue to red.
%  MapPos:        The [lon lat] position of the location to plot the
%                 symbol.
%
%  Outputs:       A symbol on the HF Radar map.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% 	$Id: PlotNonHFRadarData.m 2007-08 cmh $	
%
% Copyright (C) 2007 Christopher M. Halle
% Licence: GPL (Gnu Public License)
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
figure(TemFigHandle);
%
%  can we do all at once, or do I have to loop?
%
%  remove NaN values first
%
temmark=find(~isnan(MapPos(:,1)));
if numel(temmark)>0,
    MapPos=MapPos(temmark,:);
    ColorMatrices=ColorMatrices(temmark,:);
else
    return;
end
%
%  we have to loop in the plot routine, so find all of those locations that
%  have the same color and plot them.  We might have a problem if we
%  overplot some locations, but that is o.k.
%
%  Let us go from blue to red?
%
[NewColors,INew,JNew]=unique(ColorMatrices,'rows');
%
for jcolor=1:numel(INew),
    temmark=find(JNew==jcolor);
    if numel(temmark)>0,
        m_plot(MapPos(temmark,1),MapPos(temmark,2),SymbType,'Color',NewColors(jcolor,:),'MarkerSize',SymbSize,'LineWidth',[1]);
    end
end
%  routine is done
%
return;
%
