function [PlotCheckVal,TemFigHandle1,TemFigHandle2]=PlotRadialStatisticsSingle(RadialStats)
%
%  PlotRadialStatisticsSingle(RadialStats);
%
%  to plot the stats.  Does for a single site - modified so that the empty
%  sites show up as well (files with no data)
%
%  Find the Site Name
%
AllNames=unique(RadialStats.SiteNames);
if numel(AllNames)>1,
    [SiteToUse,ia,ib]=setxor(AllNames,{''});
    %
    %  should just be one site at this point
    %
    if numel(SiteToUse)>1,
        disp('too many sites passed to calling routine, plots not made')
        PlotCheckVal=0;
        TemFigHandle1=NaN;
        TemFigHandle2=NaN;
        return;
    end
else
    SiteToUse=AllNames;
end
%
PlotCheckVal=1;  % plots are being made
%
TemFigHandle1=figure;
subplot(4,1,1)
plot(RadialStats.FileTimeStamp,RadialStats.FileFound,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.FileFound,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.DataFound,'r')
plot(RadialStats.FileTimeStamp,RadialStats.DataFound,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[-0.1 1.1])
set(gca,'YTick',[0 1])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1})...
    ', Check for FileFound (black) and DataFound (red)'];

title(TemStr)
subplot(4,1,2)
plot(RadialStats.FileTimeStamp,RadialStats.NotWobblyFiles,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.NotWobblyFiles,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.MatchingTimeStamps,'r')
plot(RadialStats.FileTimeStamp,RadialStats.MatchingTimeStamps,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[-0.1 1.1])
set(gca,'YTick',[0 1])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for NotWobbly (black) and MatchingTimeStamps (red)'];
title(TemStr)
subplot(4,1,3)
plot(RadialStats.FileTimeStamp,RadialStats.GriddedCurrentsUnique,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.GriddedCurrentsUnique,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.NonNanGriddedCurrentsUnique,'r')
plot(RadialStats.FileTimeStamp,RadialStats.NonNanGriddedCurrentsUnique,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[-0.1 1.1])
set(gca,'YTick',[0 1])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for GridCurrUnique (black) and NonNanGridCurrUnique (red)'];
title(TemStr)
subplot(4,1,4)
plot(RadialStats.FileTimeStamp,RadialStats.PerDiffFwd,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.PerDiffFwd,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.PerDiffBack,'r')
plot(RadialStats.FileTimeStamp,RadialStats.PerDiffBack,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
MinY=min([nanmin(RadialStats.PerDiffFwd) nanmin(RadialStats.PerDiffBack)]);
MaxY=max([nanmax(RadialStats.PerDiffFwd) nanmax(RadialStats.PerDiffBack)]);
if isnan(MinY),
    MinY=0;
end
if isnan(MaxY),
    MaxY=100;
end
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[MinY-0.1 MaxY+0.1])
YDiff=(MaxY-MinY)/5;
set(gca,'YTick',[MinY:YDiff:MaxY])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for PerDiffFwd (black) and PerDiffBack (red)'];
title(TemStr)
%
TemFigHandle2=figure;
subplot(3,1,1)
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsTotal,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsTotal,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsOutSideMask,'r')
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsOutSideMask,'r.')
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsInMask,'b')
plot(RadialStats.FileTimeStamp,RadialStats.NumRadsInMask,'b.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
MinY1=nanmin(RadialStats.NumRadsTotal);
MinY2=nanmin(RadialStats.NumRadsOutSideMask);
MinY3=nanmin(RadialStats.NumRadsInMask);
MinY=min([MinY1 MinY2 MinY3]);
MaxY1=nanmax(RadialStats.NumRadsTotal);
MaxY2=nanmax(RadialStats.NumRadsOutSideMask);
MaxY3=nanmax(RadialStats.NumRadsInMask);
MaxY=max([MaxY1 MaxY2 MaxY3]);
if isnan(MinY),
    MinY=0;
end
if isnan(MaxY),
    MaxY=100;
end
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[MinY-0.1 MaxY+0.1])
YDiff=(MaxY-MinY)/5;
set(gca,'YTick',[MinY:YDiff:MaxY])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for NumRadsTotal (black) NumRadsOutSideMask(red) and NumRadsInMask (blue)'];
title(TemStr)
subplot(3,1,2)
plot(RadialStats.FileTimeStamp,RadialStats.MaxRange,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.MaxRange,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.MinRange,'r')
plot(RadialStats.FileTimeStamp,RadialStats.MinRange,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
MinY=min([nanmin(RadialStats.MinRange) nanmin(RadialStats.MaxRange)]);
MaxY=max([nanmax(RadialStats.MinRange) nanmax(RadialStats.MaxRange)]);
if isnan(MinY),
    MinY=0;
end
if isnan(MaxY),
    MaxY=100;
end
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[MinY-0.1 MaxY+0.1])
YDiff=(MaxY-MinY)/5;
set(gca,'YTick',[MinY:YDiff:MaxY])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for MaxRange (black) and MinRange (red)'];
title(TemStr)
subplot(3,1,3)
plot(RadialStats.FileTimeStamp,RadialStats.MaxBear,'k')
hold
plot(RadialStats.FileTimeStamp,RadialStats.MaxBear,'k.')
plot(RadialStats.FileTimeStamp,RadialStats.MinBear,'r')
plot(RadialStats.FileTimeStamp,RadialStats.MinBear,'r.')
set(gca,'XLim',[min(RadialStats.FileTimeStamp) max(RadialStats.FileTimeStamp)])
MinY=min([nanmin(RadialStats.MinBear) nanmin(RadialStats.MaxBear)]);
MaxY=max([nanmax(RadialStats.MinBear) nanmax(RadialStats.MaxBear)]);
if isnan(MinY),
    MinY=0;
end
if isnan(MaxY),
    MaxY=100;
end
set(gca,'XTick',[min(RadialStats.FileTimeStamp):7:max(RadialStats.FileTimeStamp)])
set(gca,'YLim',[MinY-0.1 MaxY+0.1])
YDiff=(MaxY-MinY)/5;
set(gca,'YTick',[MinY:YDiff:MaxY])
datetick('x',23,'keeplimits','keepticks')
grid on
TemStr=['Site ' char(SiteToUse{1}) ', Check for MaxBear (black) and MinBear (red)'];
title(TemStr)
%
%  the routine is done
%
return;
