function ReplaceHFRadials()
%
%  ReplaceHFRadials();
%
%  CMH, Sept 2007
%
%  To replace HF radials that have already been loaded (done, for
%  instance, if we have loaded corrupted files, there are updates, etc.)
%  Also saves radials that are not in the original set.
%
%  The parameters in this function are hardcoded, below (input directories,
%  etc.).  Note that where they should be changed, they are indicated as
%  such.
%
%  Based on the assumption that the original radials were loaded and saved
%  in groups of files.
%
%  Assumes that the old and new radials were saved with a common time base
%  (UTC, PDT, etc.)
%
%  Also assumes that the highest resolution that the files are recored in
%  is hourly (uses a small time difference to see if the files are the
%  same).
%
%  old radials saved with the variable name Rorig
%
% *****  set up the new radial information.  Change this as needed.
%
DirNames=cell(1,1);
DirNames{1} = '/Users/chrishalle/Documents/CODARData/LongRangeNearBML/BMLR/Radials/BMLR_RDLm_2007_W25_Jun/';
SiteNumber=1;
StartDate=[2007 6 11 14];  % don't have the first file at MEND, but o.k.
EndDate=[2007 6 17 11];
%EndDate=[2007 6 11 20];  % changed when testing
Spacing=1;  % spacing between radial data files in hours
SiteCodes={'BMLR'};  %  need to add to the file names - corresponds to dirname directories, in the
%  same name as those were specified
FilePre={'RDLm'};
NumFilesToGroup=100;  % !!!!!  will load 100 new radial 
%                              files at a time to check, memory saver
%
%NumFilesToGroup=4;  % changed to 4 when testing
%
%  *****  end of setting up new radial information
%
%  ***  set up the old radial information - input directory, new output
%  directory (to save under the old input directory), and the file prefix
%  for the old radials
%
OldInputDir='/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessedData/MayAug2007Dup/';
NewOutputDir='ReplacedRads';
OldFilePrefix='LRRadsMayAug2007G';  % new prefix will have R added after the old file prefix and number
%
%  radials not found will be saved with an N after the old prefix, if they
%  do not fit into the sequence.
%
%  note:  old files typically saved as numbers, LRRadsMayAug2007G1.mat,
%  LRRadsMayAug2007G2.mat, etc.
%
%  ******  end of setting up old radial information
%
%  *****  set up the log file name.  will be saved in the replacement file
%  output directory
%
LogFileOut='ReplaceLRMayAug2007Rad.txt';
%
%  end of setting up the log file name
%  ********
%  ********  end of setting up the parameters
%
%  Step 1 - set up the full new output directory name
%
FullDirNew=fullfile(OldInputDir,NewOutputDir);
%
%  Step2a - get a list of the files in the old radial file directory
%
SizeOldFilePrefix=numel(OldFilePrefix);
cd(OldInputDir);
TemDir=dir;
IsOldFile=zeros(numel(TemDir),1);
for jdir=1:numel(TemDir),
    if isequal(TemDir(jdir).isdir,0),
        if numel(TemDir(jdir).name)>(SizeOldFilePrefix+3),
            TemName=TemDir(jdir).name;
            if isequal(TemName(1:SizeOldFilePrefix),OldFilePrefix),
                if isequal(TemName(numel(TemName)-3:numel(TemName)),'.mat'),
                    IsOldFile(jdir)=1;
                end
            end
        end
    end
end
%
if sum(IsOldFile)>0,
    temmark=find(IsOldFile>0);
    IsOldFile=temmark;
    TemDir=TemDir(temmark);
else
    disp('no old radial files found')
    disp('routine ending')
    return;
end
%  Step 2b - create the new output directory.  Simply end and return if it
%  exists, because then something is wrong.
%
cd(OldInputDir);
if exist(NewOutputDir,'dir'),
    disp('the directory specified for the replacement radials')
    disp('already exists')
    disp('the routine is ending')
    return;
else
    disp('new radial output directory being created')
    mkdir(NewOutputDir)
end
%    
%  Step 3 - Start the log
%
LineForLog=['Starting the Radial Replacement Proccess'];
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
StartThisRoutine=clock;
TemStartRoutine=datestr(now);
LineForLog=['Time is (in whatever local time zone the computer is) ' TemStartRoutine];
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
LineForLog='******';
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
%
%  Step 4 - set up the replacement radial names
%
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes giives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
[FileNamesNewRads,TimesForFiles]=SetUpLRFileNames(DirNames,FilePre,TemVec,SiteCodes);
%
%  Step 5 - Loop through if we do indeed have new radials.  End if we do
%  not.
%
if numel(FileNamesNewRads)<1,
    disp('routine ending.  No new radials')
    return;
end
%
NumGroups=ceil(numel(FileNamesNewRads)/NumFilesToGroup);
%
LineForLog=[num2str(numel(FileNamesNewRads)) ' total files, using ' num2str(NumFilesToGroup) ' files per group'];
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
LineForLog=['A total of ' num2str(NumGroups) ' groups of new radial files will be loaded separately'];
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
LineForLog='******';
AddLineToLog(FullDirNew,LogFileOut,LineForLog);
%
%  because we may be starting over, (file to start with may be different),
%  we need to calculate what group number we are starting with  !!! no -
%  assume we start at 1 and work our way through.
%
CurrGroupNum=1;
%
NumNewFilesSaved=0;  % in case some new radials are found
%
for JGroupNum=CurrGroupNum:NumGroups,
    StartFileNum=((JGroupNum-1)*NumFilesToGroup)+1;
    EndFileNum=StartFileNum+NumFilesToGroup-1;
    if EndFileNum>numel(FileNamesNewRads),
        EndFileNum=numel(FileNamesNewRads);
    end
    FileTem=FileNamesNewRads(StartFileNum:EndFileNum);
    RorigReplace = loadRDLFile(FileTem);
    %
    LineForLog=['Group ' num2str(JGroupNum) ' of ' num2str(NumGroups) ' groups of replacement radials loaded'];
    AddLineToLog(FullDirNew,LogFileOut,LineForLog);
    TemTime=clock;
    TemTime=etime(TemTime,StartThisRoutine)/60;
    LineForLog=['Time elapsed since routine start:  ' num2str(TemTime) ' minutes'];
    AddLineToLog(FullDirNew,LogFileOut,LineForLog);
    %
    %  Are there any of the new radials that are not empty?
    %
    %  do this the hard way, I guess.  Probably an easier way.
    %
    IndexOfMeas=zeros(numel(RorigReplace),1);
    for jindex=1:numel(RorigReplace),
        if ~isempty(RorigReplace(jindex).SiteName),
            IndexOfMeas(jindex)=1;
        end
    end
    if sum(IndexOfMeas)>0,
        temmark=find(IndexOfMeas>0);
        IndexOfMeas=temmark;
        RorigReplace=RorigReplace(IndexOfMeas);
    else
        LineForLog=['No New Measurements Found In This Group'];
        AddLineToLog(FullDirNew,LogFileOut,LineForLog);
        LineForLog='******';
        AddLineToLog(FullDirNew,LogFileOut,LineForLog);
    end
    %
    if sum(IndexOfMeas)>0,  % load the old files and supplement if need be
        %
        IndexReplaced=zeros(numel(RorigReplace),1);  % set to one if radial set used
        %
        %  Method:  (1)  move to new directory, check if redone old file exists.
        %  If so, load file from there.  If not, move to old directory,
        %  load file from there.
        %
        for jdir=1:numel(TemDir),
            %
            TemNameOld=TemDir(jdir).name;
            TemNameNew=[TemNameOld(1:numel(TemNameOld)-4) 'R.mat'];
            cd(FullDirNew);
            if exist(TemNameNew,'file'),
                load(TemNameNew);
                FileLoaded='New';
            else
                cd(OldInputDir);
                load(TemNameOld);
                FileLoaded='Old';
            end
            %
            %  now step through, one radial measurement at a time, and
            %  check
            %
            TimesOfOldFiles=NaN*zeros(numel(Rorig),1);
            for jold=1:numel(Rorig),
                TimesOfOldFiles(jold)=Rorig(jold).TimeStamp;
            end
            %
            SiteMatch=NaN*zeros(numel(RorigReplace),1); % put the old indices here
            %                                             if a match is found
            for jrep=1:numel(RorigReplace),
                TemSer=abs(TimesOfOldFiles-RorigReplace(jrep).TimeStamp);
                TemTime=find(TemSer<=((1/24)-(0.1/24)));   %  within 0.1 of an hour
                if numel(TemTime)>0,
                    for jTemTime=1:numel(TemTime),
                        if isequal(Rorig(TemTime(jTemTime)).SiteName,RorigReplace(jrep).SiteName),
                            SiteMatch(jrep)=TemTime(jTemTime);
                        end
                    end
                end
            end
            %
            %  we now have indices where things match up
            %
            temmark=find(~isnan(SiteMatch));
            %
            if numel(temmark)>0,
                Rorig(SiteMatch(temmark))=RorigReplace(temmark);
                IndexReplaced(temmark)=1;
                for jt=1:numel(temmark),
                    LineForLog=['File ' TemNameOld ' Site ' Rorig(SiteMatch(temmark(jt))).SiteName ' replaced'];
                    disp(LineForLog)
                    AddLineToLog(FullDirNew,LogFileOut,LineForLog);
                    NewTStr=datestr(datevec(Rorig(SiteMatch(temmark(jt))).TimeStamp));
                    LineForLog=['Time Replaced is ' NewTStr];
                    disp(LineForLog)
                    AddLineToLog(FullDirNew,LogFileOut,LineForLog);
                end
                LineForLog='*******';
                AddLineToLog(FullDirNew,LogFileOut,LineForLog);
            end
            %
            %
            %  we have the modified (or unmodified) radials from one of
            %  the old files
            %
            %  now we need to check if any of the radials not selected
            %  is within the timestamp of the files
            %
            IndexNotReplaced=find(IndexReplaced==0);
            %
            if numel(IndexNotReplaced)>0,
                for jNotReplaced=1:numel(IndexNotReplaced),
                    TemTimeReplace=RorigReplace(IndexNotReplaced(jNotReplaced)).TimeStamp;
                    if ((TemTimeReplace>=nanmin(TimesOfOldFiles))&(TemTimeReplace<=nanmax(TimesOfOldFiles))),
                        IndexReplaced(IndexNotReplaced(jNotReplaced))=1;  %file will be added
                    else
                        IndexNotReplaced(jNotReplaced)=0;  % if this one should not be added
                    end
                end
                temmark=find(IndexNotReplaced>0);
                if numel(temmark)>0,
                    IndexNotReplaced=IndexNotReplaced(temmark);
                    Rorig=[Rorig;RorigReplace(IndexNotReplaced)];
                    for jt=1:numel(IndexNotReplaced),
                        LineForLog=['File ' TemNameOld ' Site ' RorigReplace(IndexNotReplaced(jt)).SiteName ' added at end of file'];
                        disp(LineForLog)
                        AddLineToLog(FullDirNew,LogFileOut,LineForLog);
                        NewTStr=datestr(datevec(RorigReplace(IndexNotReplaced(jt)).TimeStamp));
                        LineForLog=['Time Added is ' NewTStr];
                        disp(LineForLog)
                        AddLineToLog(FullDirNew,LogFileOut,LineForLog);
                    end
                    LineForLog='*******';
                    AddLineToLog(FullDirNew,LogFileOut,LineForLog);
                end
            end
            %
            %  we have now done the replacement, save the file
            %   overwrite thge new file if already saved
            %
            cd(FullDirNew);
            save(TemNameNew,'Rorig')
            %
            %  clear some of the variables that we will no longer need
            %
            clear Rorig TimesOfOldFiles SiteMatch
            %
        end
        %
        %  check for Index Replacement, save those radials that were not
        %  found
        %
        temmark=find(IndexReplaced==0);
        if numel(temmark)>0,
            Rorig=RorigReplace(temmark);
            NumNewFilesSaved=NumNewFilesSaved+1;
            TemNameNewFile=[OldFilePrefix 'N' num2str(NumNewFilesSaved) '.mat'];
            cd(FullDirNew);
            save(TemNameNewFile,'Rorig');
            LineForLog=['New Radial File Saved: ' TemNameNewFile];
            disp(LineForLog)
            AddLineToLog(FullDirNew,LogFileOut,LineForLog);
            LineForLog=['Radials Saved (listed by site and time):'];
            disp(LineForLog)
            AddLineToLog(FullDirNew,LogFileOut,LineForLog);
            for jleft=1:numel(Rorig),
                NewTStr=datestr(datevec(Rorig(jleft).TimeStamp));
                LineForLog=['Site Name: ' Rorig(jleft).SiteName ' Time: ' NewTStr];
                disp(LineForLog)
                AddLineToLog(FullDirNew,LogFileOut,LineForLog);
            end
            LineForLog=['*****'];
            AddLineToLog(FullDirNew,LogFileOut,LineForLog);
        end
        %
        clear RorigReplace IndexReplaced
        %
    end
end
%
%  the routine is done
%
return;
%
function [filenamesout,TimesOut]=SetUpLRFileNames(DirNamesIn,FilePre,TimeVect,SiteCodes)
%
%  [filenamesout]=SetUpLRFileNames(DirNamesIn,FilePre,TimeVect,SiteCodes);
%
%  TimeVect has 6 columns, year, month, day hour minute, sec (last two
%  should be zero)
%
[NumTimes,numcols]=size(TimeVect);
NumSites=numel(SiteCodes);  % should match number of directories
%
NumFilesOut=NumSites*NumTimes;
filenamesout=cell(NumFilesOut,1);
%
%  remove the year from the TimeVector, not used in the file naming
%  convention - yes, it is for these!!!!!  Line below commented out.
%
%TimeVect(:,1)=TimeVect(:,1)-2000;
%
%  David's routines set up teh file names by time, so that they loop from site to site
%  at the same time, then change the time and start over.  I'm not sure
%  that is necessary, but let's keep the convention.
%
DirSetUp=repmat(DirNamesIn,NumTimes,1);
SiteSetUp=repmat(SiteCodes,NumTimes,1);
PrefixMat=repmat(FilePre,NumTimes,1);
%
%  following a bit clugey and slow, but o.k.
%  use of reshape and deal might be better
%
TimeSetUp=NaN*ones(NumFilesOut,4);  %  year, month, day, hour
%
CurrFile=0;
%
for jtime=1:NumTimes,
    TemTime=TimeVect(jtime,1:4);
    for jsite=1:NumSites,
        CurrFile=CurrFile+1;
        TimeSetUp(CurrFile,:)=TemTime;
    end
end
%
%
SuffixMat=repmat('.ruv',NumFilesOut,1);
%
SepMat=repmat('_',NumFilesOut,1);
YearMat=cellstr(num2str(TimeSetUp(:,1)));
%
%  following is done b/c of the leading zeros in months and days
%  in file names....  could be done a different way, but not worth the time.
%
MonthMat=cell(NumFilesOut,1);
DayMat=cell(NumFilesOut,1);
HourMat=cell(NumFilesOut,1);
%
for jfile=1:NumFilesOut,
    TemMonth=TimeSetUp(jfile,2);
    TemDay=TimeSetUp(jfile,3);
    TemHour=TimeSetUp(jfile,4);
    if TemMonth<10,
        TemMonthStr=['0' num2str(TemMonth)];
    else
        TemMonthStr=num2str(TemMonth);
    end
    if TemDay<10,
        TemDayStr=['0' num2str(TemDay)];
    else
        TemDayStr=num2str(TemDay);
    end
    if TemHour<10,
        TemHourStr=['0' num2str(TemHour) '00'];
    else
        TemHourStr=[num2str(TemHour) '00'];
    end
    MonthMat{jfile}=[TemMonthStr];
    DayMat{jfile}=[TemDayStr];
    HourMat{jfile}=[TemHourStr];
end
%
temnames=strcat(PrefixMat,SepMat,SiteSetUp,SepMat,YearMat,SepMat,MonthMat,SepMat,DayMat,SepMat,HourMat,SuffixMat);
%
%  The file vectors (cell strings) are all set up
%   the built in function will not work either!  Grrr.....  write my own
%
filenamesout=fullfile_multiple(DirSetUp,temnames);
%
TimesOut=TimeSetUp;
%
%  the routine is done
%
return;
%
