function [TUVIn]=spatialInterpInterface(TUVIn)
%
%  [TUVIn]=spatialInterpInterface(TUVIn);
%
%  to do spatial interpolation.  The problem is that if some measurements
%  exist at a particular time step, but they don't exist at unique
%  positions of lat and unique positions of lon, the program will bomb.  So
%  hence the interface routine.
%
%  Loop through.  At each time, find positions with measurements.  Get
%  unique lat and lon.  If >1 unique positions in both lat and lon, leave unique switch alone.
%  Otherwise, throw it to zero.  If no points, that's o.k., the rotuine can
%  handle it.
%
%  Then spatially interpolate, reconstruct, etc.
%
%  problem!  if the positions with valid meas. are circular or square, then
%  DMK routine will bomb.  Let us try the following, and if it does not
%  work, step through time by time.
%
UniquePositionsSwitch=ones(1,numel(TUVIn.TimeStamp));
%
%NumMeasPerTime=sum(~isnan(TUVorig.U+TUVorig.V));  % Do not need this
%
for jtime=1:numel(TUVIn.TimeStamp),
    %
    temmark=find(~isnan(TUVIn.U(:,jtime)+TUVIn.V(:,jtime)));
    %
    if numel(temmark)>0,
        UniqueLons=unique(TUVIn.LonLat(temmark,1));
        UniqueLats=unique(TUVIn.LonLat(temmark,2));
        %
        if numel(UniqueLons)<2||numel(UniqueLats)<2,
            %
            UniquePositionsSwitch(jtime)=0;  % only non-unique if we have some measurements, and if those are at non-unique
            % posiions.  Times with no-measurements are conseidered unique
            % here, since that doesn't crash DMK's interpolation rotuine.
        end
    end
end
%
%  Times with non-unique measurement locations, simply NaN out the measurements and
%  then replace later.  Won't have to mess with any of the other statistics
%  later.
%
temmark=find(UniquePositionsSwitch<1);
%
try
    %
    CouldInterpolateSwitch=1;  % will stay at this value if the below statements work
    %
    if numel(temmark)>0,
        %
        TemU=TUVIn.U(:,temmark);
        TemV=TUVIn.V(:,temmark);
        %
        TUVIn.U(:,temmark)=NaN;
        TUVIn.V(:,temmark)=NaN;
        %
        TUVIn=spatialInterpTotals(TUVIn);
        %
        TUVIn.U(:,temmark)=TemU;
        TUVIn.V(:,temmark)=TemV;
        %
    else
        %
        TUVIn=spatialInterpTotals(TUVIn);
        %
    end
    %
catch
    %  means we have another problem - circular or square positions
    %  keep the times we can interpolate, replace with originals when we
    %  can't
    %
    CouldInterpolateSwitch=0;
    %
end
%
if ~CouldInterpolateSwitch,
    %
    disp('entering alternate interpolation method')
    %
    if isfield(TUVIn,'TempStats'),
        TempStatsField=TUVIn.TempStats;
        TUVIn=rmfield(TUVIn,'TempStats');
    end
    %
    if isfield(TUVIn,'SpatialStats'),
        SpatialStatsField=TUVIn.SpatialStats;
        TUVIn=rmfield(TUVIn,'SpatialStats');
    end
    %
    [NumPoints,NumTimes]=size(TUVIn.U);
    %
    for jtime=1:NumTimes,
        %
        try
            TUVInSub=subsrefTUV(TUVIn,[1:NumPoints],[jtime]);
        catch
            TUVInSub=subsrefTUV(TUVIn,[1:NumPoints],[jtime],false,false);
        end
        %
        try
            %
            TUVInSub=spatialInterpTotals(TUVInSub);
            %
            TUVIn.U(:,jtime)=TUVInSub.U;
            TUVIn.V(:,jtime)=TUVInSub.V;
            %
        catch
            %
            %  do nothing, could not interpolate
            %
        end
        %
    end
    %
    if exist('TempStatsField','var'),
        %
        TUVIn.TempStats=TempStatsField;
        %
    end
    %
    if exist('SpatialStatsField','var'),
        %
        TUVIn.SpatialStats=SpatialStatsField;
        %
    end
    %
end
%
%
%  the routine is done
%
return;
%
