function GenericPlotRadialStats(RadialSite,RadialType,FileStartNum,OneFileSwitch,YearToLoad)
%
%  GenericPlotRadialStats(RadialSite,RadialType,FileStartNum,OneFileSwitch,YearToLoad)
%
%  site SHEL added - nov 2008
%
%  June 30, 2008 - OneFileSwitch added.  If equal to one (1), it plots all
%  of the figures in a "SumamrtStats2" directory, in one postscript file
%
%  This routine loads the radials and stats already obtained, and plots
%  them by month.  The figures are saved a jpegs in a summary directory
%
%  This routine loads the radials already obtained, concatenates them (so we have one 
%  radial structure instead of many for each time), and calculates the
%  "first order" stats - basically checks for unique radials, etc.
%
%  YearToLoad added b/c of obtaining the local 2006 data
%
switch upper(RadialType)
    case 'IDEAL'
        RadialType='Ideal';
    otherwise
        RadialType='Measured';
end
%
if exist('YearToLoad','var'),
    GlobalDirIn=cell(1,1);
    GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) num2str(YearToLoad) '/Matlab/' RadialType '/FirstOrderStats/'];
    GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) num2str(YearToLoad) '/Matlab/' RadialType '/FirstOrderStats/SummaryStatsFigures'];
else
    GlobalDirIn=cell(1,1);
    GlobalDirIn{1}=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) '/Matlab/' RadialType '/FirstOrderStats/'];
    GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) '/Matlab/' RadialType '/FirstOrderStats/SummaryStatsFigures'];
end
%
if ~exist('OneFileSwitch','var')
    OneFileSwitch=0;
end
%
if OneFileSwitch,
    if exist('YearToLoad','var'),
        GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) num2str(YearToLoad) '/Matlab/' RadialType '/FirstOrderStats/SummaryStatsFigures2'];
    else
        GlobalDirOut=['/Users/chrishalle/Documents/CODARData/Radials/' upper(RadialSite) '/Matlab/' RadialType '/FirstOrderStats/SummaryStatsFigures2'];
    end
end
%
if ~exist(GlobalDirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalDirOut);
    if ~SUCCESS,
        disp('creation of output directory failed')
        disp('routine ending')
        return;
    end
end
%
if exist('YearToLoad','var'),
    RadialSiteTem=[RadialSite num2str(YearToLoad)];
else
    RadialSiteTem=RadialSite;
end
%
switch upper(RadialSiteTem)
    case 'SLID'
        SiteCode={'SLID'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/SLIDRadialMask.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2008 3 30 7];  % really only need to enter year and month of start times, but keep this way for ease
            EndDate=[2008 6 4 14];
        else
            StartDate=[2008 3 30 7];
            EndDate=[2008 6 4 14];
        end
    case 'COMM'
        SiteCode={'COMM'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/COMMRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 5 31 19];
            EndDate=[2008 5 1 17];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 5 1 17];
        end
    case 'MONT'
        SiteCode={'MONT'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/MONTRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 6 6 22];
            EndDate=[2008 5 11 3];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 4 30 22];
        end
    case 'FORT'
        SiteCode={'FORT'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CMHToolbox/NationalParkStudy/FORTRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 8 1 15];
            EndDate=[2008 5 15 16];
        else
            StartDate=[2006 7 21 0];
            EndDate=[2008 5 15 16];
        end
    case 'BMLR'
        SiteCode={'BMLR'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessingInfo/BMLRRadialMask.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 2 3 20];
            EndDate=[2008 6 12 20];
        else
            StartDate=[2007 2 3 20];
            EndDate=[2008 6 12 20];
        end
    case 'PAFS'
        %
        SiteCode={'PAFS'};
        Spacing=1;  % in hours
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/LongRangeNearBML/ProcessingInfo/MENDRadialMask.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 6 15 1];
            EndDate=[2008 6 12 21];
        else
            StartDate=[2007 6 15 20];
            EndDate=[2008 6 12 21];
        end
    case 'BML1'
        SiteCode={'BML1'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/BMLRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 20];
        else
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 20];
        end
    case 'GCVE'
        SiteCode={'GCve'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/GCVERadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 3 8 6];
            EndDate=[2008 5 9 18];
        else
            StartDate=[2007 3 8 6];
            EndDate=[2008 5 9 18];
        end
    case 'PREY'
        SiteCode={'PRey'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 12 22];
        else
            StartDate=[2007 1 1 0];
            EndDate=[2008 6 5 22];
        end
    case 'BML12006'
        %
        SiteCode={'BML1'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/BMLRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 8];
            EndDate=[2006 12 31 23];
        else
            StartDate=[2006 1 1 8];
            EndDate=[2006 12 31 23];
        end
    case 'GCVE2006'
        %
        SiteCode={'GCve'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/GCVERadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 1 8];
            EndDate=[2006 11 18 20];
        else
            StartDate=[2006 1 1 8];
            EndDate=[2006 11 18 20];
        end
    case 'PREY2006'
        %
        SiteCode={'PRey'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/StandardRangeNearBML/ProcessingInfo/PREYRadMaskIn.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2006 1 6 2];
            EndDate=[2006 12 31 23];
        else
            StartDate=[2006 1 6 2];
            EndDate=[2006 12 31 23];
        end
        %
    case 'SHEL'
        %
        SiteCode={'SHEL'};
        Spacing=1;  % in hours, just used to get time axis - clugey, based on old code
        RadialMaskFile={'/Users/chrishalle/Documents/CODARData/Radials/MaskInfo/SHELRadMaskInNoShadowZones.txt'}; % !!!!  change
        if isequal(RadialType,'Ideal'),
            StartDate=[2008 7 31 0];
            EndDate=[2008 10 20 2];
        else
            StartDate=NaN;
            EndDate=NaN;
        end
        %
    otherwise
        disp('other sites not set up yet')
        disp('routine ending')
end
%
LogFileName=[upper(RadialSite) 'RadFirstOrderStatsPlotLog' datestr(clock,30) '.txt'];  % the log file
%
%  Set up the year / month time axis to load (will correspond to the file
%  names)
%
TemStart=datenum([StartDate 0 0]);
TemEnd=datenum([EndDate 0 0]);
TimeVect=TemStart:Spacing/24:TemEnd;
TemVec=datevec(TimeVect);
%
%  problem!!!! datevec routine sometimes gives 59 minutes and 60 seconds
%  instead of converting to the next hour....  check this.
%
temmark=find((TemVec(:,5)>58)&(TemVec(:,6)>58));
if numel(temmark)>0,
    disp('converting some times to next highest hour')
    disp('standard Matlab issue with datevec command')
    TemVec(temmark,4)=TemVec(temmark,4)+1;
    TemVec(temmark,5)=0;
    TemVec(temmark,6)=0;
end
%
TemVec=round(TemVec);
%
TemVecYearMonth=TemVec(:,1:2);
TemVecYearMonth=unique(TemVecYearMonth,'rows');
[NumMonths,NumCols]=size(TemVecYearMonth);
%
TemStr=['Number of Months To Process: ' num2str(NumMonths)];
AddLineToLog(GlobalDirOut,LogFileName,TemStr);
%
FileNamesIn=SetUpRadialFileNames(GlobalDirIn,SiteCode,RadialType,TemVecYearMonth);
%
for jfile=FileStartNum:1:NumMonths,
    %
    YearMonthToProcess=TemVecYearMonth(jfile,:);
    %
    if isequal(jfile,FileStartNum),
        StartClock=clock;
    end
    %
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    TemStr=['Starting Plotting With File Number' num2str(jfile)];
    AddLineToLog(GlobalDirOut,LogFileName,TemStr);
    AddLineToLog(GlobalDirOut,LogFileName,'*****');
    %
    FileFound=1;
    %
    try
        load(FileNamesIn{jfile});
        %
    catch
        FileFound=0;
    end
    %
    if FileFound,
        %
        %  now plot up the stats
        %
        [PlotCheckVal,TemFigHandle1,TemFigHandle2]=PlotRadialStatisticsSingle(RadialStats);
        %
        if isequal(PlotCheckVal,1),
            TemFileSave1=[upper(RadialSite) RadialType 'DiagPlotY' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) 'P1.jpg'];
            TemFileSave2=[upper(RadialSite) RadialType 'DiagPlotY' num2str(YearMonthToProcess(1)) 'M' num2str(YearMonthToProcess(2)) 'P2.jpg'];
            %
            cd(GlobalDirOut);
            %
            if OneFileSwitch,
                %
                TemFileSaveName=[upper(RadialSite) RadialType 'SummaryStats.ps'];
                %
                eval(['print -f1 -dpsc -append ' TemFileSaveName])
                %
                pause(2);
                %
                eval(['print -f2 -dpsc -append ' TemFileSaveName])
                %
                pause(2);
                %
            else
                %
                figure(TemFigHandle1);
                saveas(TemFigHandle1,TemFileSave1);
                pause(2);
                figure(TemFigHandle2);
                saveas(TemFigHandle2,TemFileSave2);
                pause(2);
            end
            %
            delete(TemFigHandle1);
            delete(TemFigHandle2);
            %
            AddLineToLog(GlobalDirOut,LogFileName,'*****');
            TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' Processed'];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            disp(TemStr)
            TemStr=['Month Number ' num2str(jfile)];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
            %
            ElapsedTime=etime(clock,StartClock);
            ElapsedTime=(1/60)*ElapsedTime;
            %
            TemStr=['Elapsed Time in minutes since FileStartNum: ' num2str(ElapsedTime)];
            AddLineToLog(GlobalDirOut,LogFileName,TemStr);
            disp(TemStr)
            %
            AddLineToLog(GlobalDirOut,LogFileName,'*****');
            %
        else
            AddLineToLog(GlobalDirOut,LogFileName,'*************');
            AddLineToLog(GlobalDirOut,LogFileName,'PLOTS NOT MADE');
            AddLineToLog(GlobalDirOut,LogFileName,'**************');
        end
        %
        clear Rorig Rcat RadialStats
    else
        AddLineToLog(GlobalDirOut,LogFileName,'*****');
        TemStr=['Year ' num2str(YearMonthToProcess(1)) ' Month ' num2str(YearMonthToProcess(2)) ' NOT FOUND !!!!'];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        disp(TemStr)
        TemStr=['Month Number ' num2str(jfile)];
        AddLineToLog(GlobalDirOut,LogFileName,TemStr);
        AddLineToLog(GlobalDirOut,LogFileName,datestr(clock));
    end
end
%
%  the routine is done
%
return;
%
function [FileNamesOut]=SetUpRadialFileNames(DirIn,SiteCode,RadialType,YearMonthMatrix)
%
%  [FileNamesOut]=SetUpRadialFileNames(DirIn,SiteCode,RadialType,YearM
%  onthMatrix);
%
%  To set up the Matlab file names for input
%
%  YearMonthMatrix has two columns corresponding to the month and the year
%
[NumTimes,numcols]=size(YearMonthMatrix);
FileNamesOut=cell(NumTimes,1);
%
DirSetUp=repmat(DirIn,NumTimes,1);
SiteSetUp=repmat(SiteCode,NumTimes,1);
RadsSetUp=repmat('FirstOrderStatsRads',NumTimes,1);
RadTypeSetUp=repmat(RadialType,NumTimes,1);
YearCharMat=repmat('Y',NumTimes,1);
MonthCharMat=repmat('M',NumTimes,1);
%
YearMat=cellstr(num2str(YearMonthMatrix(:,1)));
MonthMat=cellstr(num2str(YearMonthMatrix(:,2)));
%
%  the above pads the months with zeros!!!!!  Not Good.
%
%  Clugey fix
%
for jmonth=1:numel(MonthMat),
    if YearMonthMatrix(jmonth,2)<=9,
        MonthMat{jmonth}=num2str(YearMonthMatrix(jmonth,2));
    end
end
%
SuffixMat=repmat('.mat',NumTimes,1);
%
TemNames=strcat(SiteSetUp,RadsSetUp,RadTypeSetUp,YearCharMat,YearMat,MonthCharMat,MonthMat,SuffixMat);
FileNamesOut=fullfile_multiple(DirSetUp,TemNames);
%
return;
%

