function [SatDataOK]=GetMiscSSTChl(DateStart,DateEnd)
%
%  GetMiscSSTChl(DateStart,DateEnd);
%
%  To get the 3 day smoothed SST and Chl
%
% DirBodegaLine - the directory of the BodegaLine CODAR data
%  (typically something like
%  '/Users/chrishalle/Documents/CODARData/BodegaLine/2008M9D10/'
%  The satellite data will be placed in an ancillary folder under the above
%
%  CenteredDate is the date of the cruise - we will try for 10 days before
%  and after that
%
%  DateStart and DateEnd are 3 day vectors - Year, Month, Day
%
SatDataOK=1;  %  set to zero if the routine does not create the directories ok
%
DirOutTemp=fullfile('/Users/chrishalle/Documents/CODARData','MISCSatData','SeaSurfaceTempData');
DirOutChl=fullfile('/Users/chrishalle/Documents/CODARData','MISCSatData','ChlData');
%
if ~exist(DirOutTemp,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(DirOutTemp);
    if ~SUCCESS,
        disp('creation of output directory for sat. temps failed')
        disp('routine ending')
        SatDataOK=0;
        return;
    end
end
%
if ~exist(DirOutChl,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(DirOutChl);
    if ~SUCCESS,
        disp('creation of output directory for sat. chl failed')
        disp('routine ending')
        SatDataOK=0;
        return;
    end
end
%
%  Get the months, days, and years we would like
%  Set up axis to retrieve at noon, GMT
%
StartDateNum=datenum([DateStart 12 0 0]);
EndDateNum=datenum([DateEnd 12 0 0]);
%
TimeAxisToRetrieve=StartDateNum:1:EndDateNum;
%
TimeVectToRetrieve=datevec(TimeAxisToRetrieve);
%
%  Deal with roundoff (not important here)
%
% temmark=find((TimeVectToRetrieve(:,5)>58)&(TimeVectToRetrieve(:,6)>58));
% if numel(temmark)>0,
%     disp('converting some times to next highest hour')
%     disp('standard Matlab issue with datevec command')
%     TimeVectToRetrieve(temmark,4)=TimeVectToRetrieve(temmark,4)+1;
%     TimeVectToRetrieve(temmark,5)=0;
%     TimeVectToRetrieve(temmark,6)=0;
% end
% %
% TimeVectToRetrieve=round(TimeVectToRetrieve);
%
YearMatrix=TimeVectToRetrieve(:,1);
MonthMatrix=TimeVectToRetrieve(:,2);
DaysMatrix=TimeVectToRetrieve(:,3);
%
FirstChlLinkPiece='http://coastwatch.pfel.noaa.gov/coastwatch/CWBrowser.jsp?get=gridData&dataSet=TMYchla&timePeriod=3day&centeredTime=';
LastLinkPiece='T12:00:00&maxLat=40&minLon=-126&maxLon=-122&minLat=37&fileType=.mat';
FirstTempLinkPiece='http://coastwatch.pfel.noaa.gov/coastwatch/CWBrowser.jsp?get=gridData&dataSet=TATssta&timePeriod=3day&centeredTime=';
%
for jtime=1:numel(MonthMatrix),
    %
    disp(['Satellite time number ' num2str(jtime) ' of ' num2str(numel(MonthMatrix)) ' being processed'])
    %
    %
    if MonthMatrix(jtime)<10,
        MonthPart=['0' num2str(MonthMatrix(jtime),1)];
    else
        MonthPart=num2str(MonthMatrix(jtime),2);
    end
    %
    if DaysMatrix(jtime)<10,
        DayPart=['0' num2str(DaysMatrix(jtime),1)];
    else
        DayPart=num2str(DaysMatrix(jtime),2);
    end
    %
    YearPart=num2str(YearMatrix(jtime),4);
    %
    FullLinkChl=[FirstChlLinkPiece YearPart '-' MonthPart '-' DayPart LastLinkPiece];
    FullLinkTemp=[FirstTempLinkPiece YearPart '-' MonthPart '-' DayPart LastLinkPiece];
    %
    FileChlToSave=['CHL3Day' YearPart 'M' MonthPart 'D' DayPart 'H12UTC.mat'];
    FileTempToSave=['SST3Day' YearPart 'M' MonthPart 'D' DayPart 'H12UTC.mat'];
    %
    cd(DirOutChl)
    %
    try
        F=urlwrite(FullLinkChl,FileChlToSave);
        pause(10);
        temstr=['CHL' YearPart 'M ' MonthPart 'D' DayPart];
        disp(temstr)
        disp('    ')
        dir
    catch
        disp('Chlorophyll file not written')
        temstr=[YearPart ' M ' MonthPart 'D' DayPart];
        disp(temstr)
    end
    %
    cd(DirOutTemp)
    %
    try
        F=urlwrite(FullLinkTemp,FileTempToSave);
        pause(10);
        temstr=['TEMP ' YearPart ' M ' MonthPart 'D' DayPart];
        disp(temstr)
        disp('    ')
        dir
    catch
        disp('Temp file not written')
        temstr=[YearPart ' M ' MonthPart 'D' DayPart];
        disp(temstr)
    end
    %
end
%
%  the routine is done
%
return;
%
