function [FormPlots]=MakeSatPlotsNew(DataDir,DataType,LonLimits,LatLimits,DateStart,DateEnd)
%
%  [FormPlots]=MakeSatPlotsNew(DataDir,DataType,LonLims,LatLims,DateStart,D
%  ateEnd);
%
%  Makes a new directory /Images!  Old pictures are overwritten, bt not
%  deleted.
%
%  Assumes we have daily estimates
%
DirOut=fullfile(DataDir,'Images');
%
CoastFile=fullfile('/Users/chrishalle/Documents/CODARData/Totals/StatewideFromSYKim/ProcessingInfo','WestCoastMap.mat');
%
if ~exist(DirOut,'dir'),
    %
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(DirOut);
    if ~SUCCESS,
        disp('creation of output directory for failed')
        disp('routine ending')
        FormPlots=0;
        return;
    end
end
%
switch upper(DataType)
    case 'AVHRRSST3DAY'
        ParamFileStart='SST3Day';
        ParamVarName='ATssta';
        ParamContourLevels=[8:0.5:20];
    case 'AQUACHL3DAY'
        ParamFileStart='CHL3Day';
        ParamVarName='MYchla';
        ParamContourLevels=[-1:0.5:3];
    case 'EXPAQUACHL3DAY'  % sensor on a different satellite?
        ParamFileStart='EXPCHL3Day';
        ParamVarName='MWchla';
        ParamContourLevels=[-1:0.5:3];
    case 'BLENDEDSST5DAY'
        ParamFileStart='BLNDSST5Day';
        ParamVarName='BAssta';
        ParamContourLevels=[8:0.5:20];
    case 'GOESSST3DAY'
        ParamFileStart='GOESSST3Day';
        ParamVarName='GAssta';
        ParamContourLevels=[8:0.5:20];
    case 'ZONALBLENDEDWIND1DAY'
        ParamFileStart='BLNDZONWIND1Day';
        ParamVarName='NWuuuu';
        ParamContourLevels=[-10:1:10];
    case 'MERIDIONALBLENDEDWIND1DAY'
        ParamFileStart='BLNDMERWIND1Day';
        ParamVarName='NWvvvv';
        ParamContourLevels=[-10:1:10];
    case 'ZONALQSCATWINDS1DAY'
        ParamFileStart='QSCATZONWIND1Day';
        ParamVarName='QNux10';
        ParamContourLevels=[-10:1:10];
    case 'MERIDIONALQSCATWINDS1DAY'
        ParamFileStart='QSCATMERWIND1Day';
        ParamVarName='QNuy10';
        ParamContourLevels=[-10:1:10];
    case 'ZONALQSCATWINDS3DAY'
        ParamFileStart='QSCATZONWIND3Day';
        ParamVarName='QNux10';
        ParamContourLevels=[-10:1:10];
    case 'MERIDIONALQSCATWINDS3DAY'
        ParamFileStart='QSCATMERWIND3Day';
        ParamVarName='QNuy10';
        ParamContourLevels=[-10:1:10];
    case 'AVISOSSH1DAY'
        ParamFileStart='SSH1Day';
        ParamVarName='TAsshl';
        ParamContourLevels=[1.5:0.05:2];
    case 'AVISOSSHDEVIATION1DAY'
        ParamFileStart='SSHDev1DDay';
        ParamVarName='TAsshd';
        ParamContourLevels=[-0.15:0.015:0.15];
    case 'CHLSEAWIFS3DAY'  % data ends in March 2009
        ParamFileStart='SWIFS3Day';
        ParamVarName='SHchl2';
        ParamContourLevels=[-1:0.5:3];
    case 'CHLADEVIATIONSEAWIFS8DAY' % data ends in March 2009
        ParamFileStart='SWIFSDev8Day';
        ParamVarName='SHcde2';
        ParamContourLevels=[-2:0.2:2];
    case 'ZONGEOCURRENTS1DAY'  %  as of Jul 2009, data available until Dec 2008
        ParamFileStart='GEOCurrZon1Day';
        ParamVarName='TAugeo';
        ParamContourLevels=[-0.5:0.1:0.5];
    case 'MERGEOCURRENTS1DAY'
        ParamFileStart='GEOCurrMer1Day';
        ParamVarName='TAvgeo';
        ParamContourLevels=[-0.5:0.1:0.5];
    otherwise
        disp('unknown option chosen')
        disp('routine ending')
        return;
end
%
StartDateNum=datenum([DateStart 12 0 0]);
EndDateNum=datenum([DateEnd 12 0 0]);
%
TimeAxisToRetrieve=StartDateNum:1:EndDateNum;
%
TimeVectToRetrieve=datevec(TimeAxisToRetrieve);
%
%  now get the file names
%
[FileNamesToLoad]=SetUpFileNames(DataDir,ParamFileStart,TimeVectToRetrieve);
%
%  FilenamesToLoad should have one entry (or a NaN) for each row of
%  TimeVectToRetrieve
%
if ~iscell(FileNamesToLoad),
    disp('no files found')
    disp('routine ending')
    FormPlots=0;
    return;
end
%
%  Make the plots and save
%
for jtime=1:numel(FileNamesToLoad),
    %
    TemFigHandle=figure;
    %
    plotBasemap(LonLimits,LatLimits,CoastFile,'lambert', 'patch', [0.5 0.5 0.5] );
    hold
    xlabel('longitude, (degrees)','FontSize',[12],'FontWeight','bold')
    ylabel('latitude, (degrees)','FontSize',[12],'FontWeight','bold')
    %
    TemTitle=[ParamFileStart ' ' datestr(datenum(TimeVectToRetrieve(jtime,:)),1)];
    title(TemTitle);
    %
    try
       load(char(FileNamesToLoad{jtime}));
    catch
        lon=1:10;
        lat=1:3;
        eval([ParamVarName '=NaN*ones(3,10);'])
    end
    %
    eval(['DataToPlot=' ParamVarName ';'])
    eval(['clear ' ParamVarName])
    %
    switch upper(DataType)
        case 'AQUACHL3DAY'
            DataToPlot=log10(DataToPlot);
        case 'EXPAQUACHL3DAY'  % sensor on a different satellite?
            DataToPlot=log10(DataToPlot);
        case 'CHLSEAWIFS3DAY'  % data ends in March 2009
            DataToPlot=log10(DataToPlot);
        case 'CHLADEVIATIONSEAWIFS8DAY' % data ends in March 2009
            DataToPlot=sign(DataToPlot).*log10(DataToPlot);
        otherwise
            %  do nothing
    end
    %
    temmark=find(DataToPlot>max(ParamContourLevels));
    if numel(temmark)>0,
        DataToPlot(temmark)=max(ParamContourLevels);
    end
    %
    temmark=find(DataToPlot<min(ParamContourLevels));
    if numel(temmark)>0,
        DataToPlot(temmark)=min(ParamContourLevels);
    end
    %
    if sum(sum(isfinite(DataToPlot)))>0,
        [cs,h]=m_contourf(lon,lat,DataToPlot,ParamContourLevels);
    end
    %
    caxis([min(ParamContourLevels) max(ParamContourLevels)])
    colorbar('vert')
    %
    TemFigName=[DataType num2str(TimeVectToRetrieve(jtime,1)) 'M' num2str(TimeVectToRetrieve(jtime,2)) 'D' num2str(TimeVectToRetrieve(jtime,3)) 'H12GMT.jpg'];
    %
    cd(DirOut);
    %
    saveas(TemFigHandle,TemFigName,'jpg');
    pause(2);
    delete(TemFigHandle);
    %
end
%
FormPlots=1;
%
%  the routine is done
%
return;
%
function [FileNamesToLoad]=SetUpFileNames(DataDir,ParamFileStart,TimeVectToRetrieve)
%
%  [FileNamesToLoad]=SetUpFileNames(DataDir,ParamFileStart,TimeVectToRetrie
%  ve);
%
[NumTimes,NumCols]=size(TimeVectToRetrieve);
%
FilesFound=0;
%
FileNamesToLoad=cell(NumTimes,1);
%
cd(DataDir);
%
for jtime=1:NumTimes,
    %
    if TimeVectToRetrieve(jtime,2)<10,
        MonthPart=['0' num2str(TimeVectToRetrieve(jtime,2),1)];
    else
        MonthPart=num2str(TimeVectToRetrieve(jtime,2),2);
    end
    %
    if TimeVectToRetrieve(jtime,3)<10,
        DayPart=['0' num2str(TimeVectToRetrieve(jtime,3),1)];
    else
        DayPart=num2str(TimeVectToRetrieve(jtime,3),2);
    end
    %    
    FileToCheck=[ParamFileStart num2str(TimeVectToRetrieve(jtime,1)) 'M' MonthPart ...
        'D' DayPart 'H12UTC.mat'];
    %
    if exist(FileToCheck,'file'),
        FileNamesToLoad{jtime}=fullfile(DataDir,FileToCheck);
        FilesFound=FilesFound+1;
    else
        FileNamesToLoad{jtime}=NaN;
    end
    %
end
%
if isequal(FilesFound,0),
    FileNamesToLoad=NaN;
end
%
return;
%
