function MoveRadialTem(InputRadialDir,RadialSite,OutPutRadialDir)
%
%  MoveRadialTem(InputRadialDir,RadialSite,OutPutRadialDir);
%
%  modified from MoveRadialFilesMontBay - done to move files from the
%  multiple input directories to one
%
%  files can be in directories one level down from the input directory
%
%  InputRadialDir is case sensitive!!!! (ex--->
%  InputRadialDir='GCVESinceMay2008/Halle GCVE')
%
%  so is OutPutRadialDir
%
%  To move files from the multiple directories given to one directory
%  Done for the files from Monterey / Santa Cruz passed to me by Julio
%
%  RadialSite is the site (COMM, BML1, etc.)  Set up for my directory
%  structure
%  RadialType is either "Measured" or "Ideal".  If not Ideal, measured is
%  assumed.
%
%  First part of directory names has to begin with the RadialSite - other
%  directories are ignored.  Could add a check for number of characters
%  instead, but this should work.
%  Modified so that first part of directory names do not need to begin with
%  radial site.  They must simply have more than 4 characters to be
%  considered.
%
GlobalInputDir=['/Users/chrishalle/Documents/CODARData/Radials/' InputRadialDir];
GlobalOutputDirIdeal=['/Users/chrishalle/Documents/CODARData/Radials/' OutPutRadialDir '/IdealAll'];
GlobalOutputDirMeasured=['/Users/chrishalle/Documents/CODARData/Radials/' OutPutRadialDir '/MeasuredAll'];
%
if exist(GlobalOutputDirIdeal,'dir'),
    DirCheck='IdealOutputDirectoryExists';
else
    DirCheck='IdealOutputDirectoryCreated';
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalOutputDirIdeal);
    if ~SUCCESS,
        disp('directory attempt failed')
        disp('routine ending')
        return;
    end
end
%
LogFileNameIdeal=[RadialSite 'IdealMoveLog' datestr(clock,30) '.txt'];
%
AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,DirCheck);
%
if exist(GlobalOutputDirMeasured,'dir'),
    DirCheck='MeasuredOutputDirectoryExists';
else
    DirCheck='MeasuredOutputDirectoryCreated';
    [SUCCESS,MESSAGE,MESSAGEID] = mkdir(GlobalOutputDirMeasured);
    if ~SUCCESS,
        disp('directory attempt failed')
        disp('routine ending')
        return;
    end
end
%
LogFileNameMeasured=[RadialSite 'MeasuredMoveLog' datestr(clock,30) '.txt'];
%
AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,DirCheck);
%
InitialSize=1000;  %assume we have 1000 files, trim later if need be
DirNamesInIdeal=cell(InitialSize,1);
FileNamesInIdeal=cell(InitialSize,1);
DirNamesInMeasured=cell(InitialSize,1);
FileNamesInMeasured=cell(InitialSize,1);
%
cd(GlobalInputDir);
%
%  Get the directories and file names to move
%
FilesFoundIdeal=0;
FilesFoundMeasured=0;
%
TemDir=dir;
%
for jdir=1:numel(TemDir),
    if TemDir(jdir).isdir,
        if numel(TemDir(jdir).name)>=numel(RadialSite),
            %if isequal(upper(TemDir(jdir).name(1:numel(RadialSite))),upper(RadialSite)), % we might have a directory with files in it
            if numel(TemDir(jdir).name)>=4, % This is now redundant, but easier than modifying the code above    
                %
                cd(TemDir(jdir).name);  % now in the directory.  Now check for file names
                %
                TemFileDir=dir;
                %
                %  assume it's a file we want if the file names are long
                %  enough
                %
                for jfile=1:numel(TemFileDir),
                    if ~TemFileDir(jfile).isdir, % we want files, not directories
                        if numel(TemFileDir(jfile).name)>=15, %15 is arbitrary
                            %
                            DirWantNow=fullfile(GlobalInputDir,TemDir(jdir).name);
                            FileWantNow=TemFileDir(jfile).name;
                            %
                            if isequal(upper(FileWantNow(1:4)),'RDLI'),
                                FilesFoundIdeal=FilesFoundIdeal+1;
                                if FilesFoundIdeal>numel(DirNamesInIdeal),
                                    %
                                    DirNamesInIdeal=[DirNamesInIdeal;cell(InitialSize,1)];
                                    FileNamesInIdeal=[FileNamesInIdeal;cell(InitialSize,1)];
                                end
                                DirNamesInIdeal{FilesFoundIdeal}=DirWantNow;
                                FileNamesInIdeal{FilesFoundIdeal}=FileWantNow;
                            elseif isequal(upper(FileWantNow(1:4)),'RDLM'),
                                FilesFoundMeasured=FilesFoundMeasured+1;
                                if FilesFoundMeasured>numel(DirNamesInMeasured),
                                    %
                                    DirNamesInMeasured=[DirNamesInMeasured;cell(InitialSize,1)];
                                    FileNamesInMeasured=[FileNamesInMeasured;cell(InitialSize,1)];
                                end
                                DirNamesInMeasured{FilesFoundMeasured}=DirWantNow;
                                FileNamesInMeasured{FilesFoundMeasured}=FileWantNow;
                            else
                                %  a file that is nether ideal nor measured
                                %  just display it
                                disp('File that is neither ideal nor measured')
                                disp(['Directory: ' DirWantNow])
                                disp(['File: ' FileWantNow])
                            end
                        end
                    end
                end
                %
                %
                %  now change directories back up one level
                %
                cd ..
                %
            end
        end
    end
end
%
%
%  now trim the file and directory matrices
%
DirNamesInIdeal=DirNamesInIdeal(1:FilesFoundIdeal,:);
FileNamesInIdeal=FileNamesInIdeal(1:FilesFoundIdeal,:);
DirNamesInMeasured=DirNamesInMeasured(1:FilesFoundMeasured,:);
FileNamesInMeasured=FileNamesInMeasured(1:FilesFoundMeasured,:);
%
%  we have the lists of files at this point
%
MoveFileSuccess=1;  % will set this to zero if we get any errors
%
for jfile=1:FilesFoundIdeal,
    %
    if isequal(rem(jfile,100),0),
        temstr=['Site: ' RadialSite ' File Number ' num2str(jfile) ' of ' num2str(FilesFoundIdeal) ' Being Copied'];
        disp(temstr);
    end
    %
    FileToMove=fullfile(DirNamesInIdeal{jfile},FileNamesInIdeal{jfile});
    FileNewName=fullfile(GlobalOutputDirIdeal,FileNamesInIdeal{jfile});  % moving all files to the same directory
    %
    %[STATUS,MESSAGE,MESSAGEID]=movefile(FileToMove,FileNewName);
    [STATUS,MESSAGE,MESSAGEID]=copyfile(FileToMove,FileNewName);
    %
    if ~STATUS,
        %
        MoveFileSuccess=0;
        %
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'                     ');
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'*********************');
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'FileNotCopiedCorrectly');
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,['FileName: ' FileToMove]);
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,MESSAGE);
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'*********************');
        AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'                     ');
        %
    end
end
%
if MoveFileSuccess,
    %
    AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'                     ');
    AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'*********************');
    AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'AllFilesMovedCorrectly');
    AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'*********************');
    AddLineToLog(GlobalOutputDirIdeal,LogFileNameIdeal,'                     ');
end
%
%
%  we have the lists of files at this point
%
MoveFileSuccess=1;  % will set this to zero if we get any errors
%
for jfile=1:FilesFoundMeasured,
    %
    if isequal(rem(jfile,100),0),
        temstr=['Site: ' RadialSite ' File Number ' num2str(jfile) ' of ' num2str(FilesFoundMeasured) ' Being Copied'];
        disp(temstr);
    end
    %
    FileToMove=fullfile(DirNamesInMeasured{jfile},FileNamesInMeasured{jfile});
    FileNewName=fullfile(GlobalOutputDirMeasured,FileNamesInMeasured{jfile});  % moving all files to the same directory
    %
    %[STATUS,MESSAGE,MESSAGEID]=movefile(FileToMove,FileNewName);
    [STATUS,MESSAGE,MESSAGEID]=copyfile(FileToMove,FileNewName);
    %
    if ~STATUS,
        %
        MoveFileSuccess=0;
        %
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'                     ');
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'*********************');
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'FileNotCopiedCorrectly');
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,['FileName: ' FileToMove]);
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,MESSAGE);
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'*********************');
        AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'                     ');
        %
    end
end
%
if MoveFileSuccess,
    %
    AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'                     ');
    AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'*********************');
    AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'AllFilesMovedCorrectly');
    AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'*********************');
    AddLineToLog(GlobalOutputDirMeasured,LogFileNameMeasured,'                     ');
end
%  the routine is ended
%
return;
%
